@@ -3,9 +3,8 @@ package multigitter
 import (
 	"context"
 
+	"github.com/lindell/multi-gitter/internal/scm"
 	log "github.com/sirupsen/logrus"
-
-	"github.com/lindell/multi-gitter/internal/domain"
 )
 
 // Merger merges pull requests in an organization
@@ -22,9 +21,9 @@ func (s Merger) Merge(ctx context.Context) error {
 		return err
 	}
 
-	successPrs := make([]domain.PullRequest, 0, len(prs))
+	successPrs := make([]scm.PullRequest, 0, len(prs))
 	for _, pr := range prs {
-		if pr.Status() == domain.PullRequestStatusSuccess {
+		if pr.Status() == scm.PullRequestStatusSuccess {
 			successPrs = append(successPrs, pr)
 		}
 	}
@@ -32,10 +31,12 @@ func (s Merger) Merge(ctx context.Context) error {
 	log.Infof("Merging %d pull requests", len(successPrs))
 
 	for _, pr := range successPrs {
-		log.WithField("pr", pr.String()).Infof("Merging")
+		log := log.WithField("pr", pr.String())
+
+		log.Infof("Merging")
 		err := s.VersionController.MergePullRequest(ctx, pr)
 		if err != nil {
-			return err
+			log.Errorf("Error occurred while merging: %s", err.Error())
 		}
 	}
 
