@@ -2,6 +2,8 @@ package repocounter
 
 import (
 	"fmt"
+	"maps"
+	"slices"
 	"strings"
 	"sync"
 
@@ -21,6 +23,18 @@ type repoInfo struct {
 	pullRequest scm.PullRequest
 }
 
+func (ri repoInfo) String() string {
+	if ri.pullRequest == nil {
+		return ri.repository.FullName()
+	} else {
+		if urler, hasURL := ri.pullRequest.(urler); hasURL && urler.URL() != "" {
+			return terminal.Link(ri.pullRequest.String(), urler.URL())
+		} else {
+			return ri.pullRequest.String()
+		}
+	}
+}
+
 // NewCounter create a new repo counter
 func NewCounter() *Counter {
 	return &Counter{
@@ -68,33 +82,20 @@ func (r *Counter) Info() string {
 
 	var exitInfo string
 
-	for errMsg := range r.errors {
+	errors := slices.Collect(maps.Keys(r.errors))
+	slices.Sort(errors)
+
+	for _, errMsg := range errors {
 		exitInfo += fmt.Sprintf("%s:\n", strings.ToUpper(errMsg[0:1])+errMsg[1:])
 		for _, errInfo := range r.errors[errMsg] {
-			if errInfo.pullRequest == nil {
-				exitInfo += fmt.Sprintf("  %s\n", errInfo.repository.FullName())
-			} else {
-				if urler, hasURL := errInfo.pullRequest.(urler); hasURL && urler.URL() != "" {
-					exitInfo += fmt.Sprintf("  %s\n", terminal.Link(errInfo.pullRequest.String(), urler.URL()))
-				} else {
-					exitInfo += fmt.Sprintf("  %s\n", errInfo.pullRequest.String())
-				}
-			}
+			exitInfo += fmt.Sprintf("  %s\n", errInfo.String())
 		}
 	}
 
 	if len(r.successRepositories) > 0 {
 		exitInfo += "Repositories with a successful run:\n"
-		for _, repo := range r.successRepositories {
-			if repo.pullRequest != nil {
-				if urler, hasURL := repo.pullRequest.(urler); hasURL && urler.URL() != "" {
-					exitInfo += fmt.Sprintf("  %s\n", terminal.Link(repo.pullRequest.String(), urler.URL()))
-				} else {
-					exitInfo += fmt.Sprintf("  %s\n", repo.pullRequest.String())
-				}
-			} else {
-				exitInfo += fmt.Sprintf("  %s\n", repo.repository.FullName())
-			}
+		for _, repoInfo := range r.successRepositories {
+			exitInfo += fmt.Sprintf("  %s\n", repoInfo.String())
 		}
 	}
 
