@@ -79,6 +79,10 @@ type RepositoryReference struct {
 	Name      string
 }
 
+func (r RepositoryReference) String() string {
+	return fmt.Sprintf("%s/%s", r.OwnerName, r.Name)
+}
+
 // ParseRepositoryReference parses a repository reference from the format "ownerName/repoName"
 func ParseRepositoryReference(val string) (RepositoryReference, error) {
 	split := strings.Split(val, "/")
@@ -361,7 +365,7 @@ func (g *Gitea) UpdatePullRequest(ctx context.Context, repo scm.Repository, pull
 
 	giteaPr, _, err := g.giteaClient(ctx).EditPullRequest(r.ownerName, r.name, pr.index, gitea.EditPullRequestOption{
 		Title:     prTitle,
-		Body:      updatedPR.Body,
+		Body:      &updatedPR.Body,
 		Assignees: updatedPR.Assignees,
 		Labels:    labels,
 	})
