@@ -3,16 +3,17 @@ package github
 import (
 	"context"
 	"fmt"
+	"maps"
 	"net/http"
+	"slices"
 	"sort"
 	"strings"
 	"sync"
 	"time"
 
-	"github.com/google/go-github/v64/github"
+	"github.com/google/go-github/v70/github"
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
-	"golang.org/x/exp/maps"
 	"golang.org/x/oauth2"
 
 	"github.com/lindell/multi-gitter/internal/scm"
@@ -391,7 +392,7 @@ func (g *Github) getCodeSearchRepositories(ctx context.Context, search string) (
 
 	// Code search does not return full details (like permissions). So for each
 	// repo discovered, we have to query it again.
-	repoNames := maps.Values(resultRepos)
+	repoNames := slices.Collect(maps.Values(resultRepos))
 	return g.getAllRepositories(ctx, repoNames)
 }
 
@@ -444,6 +445,12 @@ func (g *Github) CreatePullRequest(ctx context.Context, repo scm.Repository, prR
 		return nil, err
 	}
 
+	if newPR.AutoMerge {
+		if err := g.enableAutoMerge(ctx, r, pr); err != nil {
+			return nil, err
+		}
+	}
+
 	return convertPullRequest(pr), nil
 }
 
@@ -568,6 +575,49 @@ func (g *Github) setLabels(ctx context.Context, repo repository, newPR scm.NewPu
 	return nil
 }
 
+func (g *Github) enableAutoMerge(ctx context.Context, _ repository, pr *github.PullRequest) error {
+	// Use GraphQL API to enable auto-merge since the REST API doesn't have a direct endpoint
+	// GitHub GraphQL mutation: enablePullRequestAutoMerge
+
+	// Use the first merge type from the configured merge types
+	var graphqlMergeMethod string
+	if len(g.MergeTypes) > 0 {
+		switch g.MergeTypes[0] {
+		case scm.MergeTypeMerge:
+			graphqlMergeMethod = "MERGE"
+		case scm.MergeTypeSquash:
+			graphqlMergeMethod = "SQUASH"
+		case scm.MergeTypeRebase:
+			graphqlMergeMethod = "REBASE"
+		default:
+			graphqlMergeMethod = "MERGE" // Default fallback
+		}
+	} else {
+		graphqlMergeMethod = "MERGE" // Default fallback if no merge types configured
+	}
+
+	query := `
+		mutation enableAutoMerge($pullRequestId: ID!, $mergeMethod: PullRequestMergeMethod!) {
+			enablePullRequestAutoMerge(input: {
+				pullRequestId: $pullRequestId,
+				mergeMethod: $mergeMethod
+			}) {
+				pullRequest {
+					id
+				}
+			}
+		}`
+
+	variables := map[string]interface{}{
+		"pullRequestId": pr.GetNodeID(),
+		"mergeMethod":   graphqlMergeMethod,
+	}
+
+	var result interface{} // We don't need to parse the result
+
+	return g.makeGraphQLRequestWithRetry(ctx, query, variables, &result)
+}
+
 // UpdatePullRequest updates an existing pull request
 func (g *Github) UpdatePullRequest(ctx context.Context, repo scm.Repository, pullReq scm.PullRequest, updatedPR scm.NewPullRequest) (scm.PullRequest, error) {
 	r := repo.(repository)
@@ -599,6 +649,12 @@ func (g *Github) UpdatePullRequest(ctx context.Context, repo scm.Repository, pul
 		return nil, err
 	}
 
+	if updatedPR.AutoMerge {
+		if err := g.enableAutoMerge(ctx, r, ghPR); err != nil {
+			return nil, err
+		}
+	}
+
 	return convertPullRequest(ghPR), nil
 }
 
@@ -690,7 +746,7 @@ func (g *Github) getPullRequests(ctx context.Context, branchName string, repos [
 	)
 
 	result := map[string]graphqlRepo{}
-	err := g.makeGraphQLRequest(ctx, query, queryVariables, &result)
+	err := g.makeGraphQLRequestWithRetry(ctx, query, queryVariables, &result)
 	if err != nil {
 		return nil, err
 	}
