@@ -71,6 +71,10 @@ type ProjectReference struct {
 	Name      string
 }
 
+func (p ProjectReference) String() string {
+	return fmt.Sprintf("%s/%s", p.OwnerName, p.Name)
+}
+
 // ParseProjectReference parses a repository reference from the format "ownerName/repoName"
 func ParseProjectReference(val string) (ProjectReference, error) {
 	lastSlashIndex := strings.LastIndex(val, "/")
@@ -258,6 +262,14 @@ func (g *Gitlab) CreatePullRequest(ctx context.Context, repo scm.Repository, prR
 		return nil, err
 	}
 
+	// Enable auto-merge if requested
+	if newPR.AutoMerge {
+		err = g.enableAutoMerge(ctx, r, mr)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	return pullRequest{
 		repoName:   r.name,
 		ownerName:  r.ownerName,
@@ -333,6 +345,13 @@ func (g *Gitlab) UpdatePullRequest(ctx context.Context, repo scm.Repository, pul
 		return nil, err
 	}
 
+	if updatedPR.AutoMerge {
+		err = g.enableAutoMerge(ctx, r, mr)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	return pullRequest{
 		repoName:   r.name,
 		ownerName:  r.ownerName,
@@ -538,3 +557,13 @@ func (g *Gitlab) getCurrentUser(ctx context.Context) (*gitlab.User, error) {
 
 	return user, nil
 }
+
+func (g *Gitlab) enableAutoMerge(ctx context.Context, repo repository, mr *gitlab.MergeRequest) error {
+	mergeWhenPipelineSucceeds := true
+
+	_, _, err := g.glClient.MergeRequests.AcceptMergeRequest(repo.pid, mr.IID, &gitlab.AcceptMergeRequestOptions{
+		MergeWhenPipelineSucceeds: &mergeWhenPipelineSucceeds,
+	}, gitlab.WithContext(ctx))
+
+	return err
+}
